<?php

//    include/header.inc
//    Global variables declaration
//
//    Part of the ht://Check package
//
//    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
//    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
//
//    For copyright details, see the file COPYING in your distribution
//    or the GNU General Public License version 2 or later 
//    <http://www.gnu.org/copyleft/gpl.html>
//
//    $Id: header.inc.php,v 1.9 2004/06/29 10:06:39 angusgb Exp $

if ( defined( '__HEADER_INC' ) ) return;
define( '__HEADER_INC', 1 );

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<html lang="<?php echo $Language; ?>">
<head>
<title>ht://Check <?php echo $Organisation; ?> / <?php echo $pagetitle; ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<meta name="generator" content="ht://Check's PHP interface">
<link rel="stylesheet" href="css/main.css" type="text/css">
<link type="text/css" rel="stylesheet" href="css/print.css" media="print">
<link type="image/x-icon" rel="shortcut icon" href="img/htcheck.ico">
</head>

<body>

<div id="header">
<div id="company"><strong>ht://Check @ <?php echo $Organisation; ?></strong></div>

<div class="img">
<img src="img/htcheck.png" width="158" height="50" alt="ht://Check logo">
</div>

<div class="toolbar">
<?php echo $linkbar; ?>
</div>
<br style="clear: both">
</div>

<br style="clear: both">

<div id="main">
