<?php

//    include/de.inc.php
//    German sentences and messages
//
//    Part of the ht://Check package
//
//    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
//    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
//    Provided by: Stenitzer Michael <stenitzer@eva.ac.at>
//
//    For copyright details, see the file COPYING in your distribution
//    or the GNU General Public License version 2 or later 
//    <http://www.gnu.org/copyleft/gpl.html>
//
//    $Id: de.inc.php,v 1.25 2006/08/24 12:53:21 angusgb Exp $

if ( defined( '__GERMAN_INC' ) ) return;
define( '__GERMAN_INC', 1 );

/* Main Page */
$strMainPage   =  "Main Page";
$strNumDBs     =  "\$numdbs; ht://Check Databank/en wurde/n am ausgew&auml;hlten Host gefunden.";
$strNoDBs      =  "Sorry. Es wurden keine ht://Check Datenbanken am ausgew&uml;hlten Host gefunden.";
$strChooseaDB  =  "W&auml;hlen Sie die gew&uuml;nschte ht://Check Datenbank";
$strSelectaDB  =  "W&auml;hlen Sie eine Datenbank";

/* Main page of a database */

$strDBSelected =  "Datenbank '<strong>\$dbname;</strong>' gew&auml;hlt";
$strGeneralInfo   = "Allgemeine Informationen";
$strServersEncountered  =  "Anzahl der gefundenen Server";
$strScheduledURLS =  "Gefundene URLS (&uuml;berpr&uuml;fte und verworfene)";
$strRetrievedURLS =  "Geladene URLS";
$strHTMLStatements   =  "HTML Elemente";
$strHTMLAttributes   =  "HTML Attribute";
$strLinks      =  "Links";
$strShowListUrls        =  "Vollst&auml;ndige Liste der URLs anzeigen";
$strShowListUrlsSeen    =  "Liste der URLs die &uuml;berpr&uuml;ft wurden";
$strShowNotFoundUrls    =  "Liste der nicht gefundenen URLs (Status Code 404)";
$strShowListLinks       =  "Liste der &uuml;berpr&uuml;ften Links anzeigen";
$strShowListUrlsFltr    =  "Liste der geladenen URLs anzeigen (mit Filter)";

$strHTTPRequestsResults    =  "Zusammenfassung der Ergebnisse der HTTP Requests";
$strServersSeenOrdIDServer =  "Zusammenfassung der HTTP Server die gefunden wurden (in der Reihenfolge der Abfrage)";
$strConnectionResults      =  "Zusammenfassung der Ergebnisse der Verbindungen";
$strContentTypeResults     =  "Zusammenfassung der gefundenen Content-Types";
$strCookiesReport     =  "Zusammenfassung der gefundenen 'cookies'";
$strUser    =  "MySQL User";
$strStartTime  = "Start";
$strEndTime  = "Ende";

/* Sections */
$strListofUrls =  "Liste der geladenen Urls";
$strListofAllUrls =  "Liste der geladenen und nicht geladenen Urls";
$strListofLinks =  "Liste der Links";
$strShowUrl    =  "URL info";
$strShowLink   =  "Link info";
$strShowUrlSource    =  "URL Quelltext";
$strDBHome =  "'<strong>\$dbname;</strong>' Home Page";
$strDBDeletion =  "Datenbank l&ouml;schen";
$strDBDeleted  =  "Datenbank '<strong>\$dbname;</strong>' gel&ouml;scht";

/* General */

$strUrl              =  "URL";
$strRequests         =  "Requests";
$strProtocol         =  "Protokoll";
$strConnectionStatus =  "Verbindungsstatus";
$strContentType      =  "Content type";
$strCharset          =  "Charset";
$strDoctype          =  "Doctype";
$strContentLanguage  =  "Content language";
$strTransferEncoding =  "Transfer Encoding";
$strStatusCode       =  "Status Code";
$strReasonPhrase     =  "Beschreibung";
$strNumber           =  "Nummer";
$strNoOccurrencies   =  "Kein Eintrag gefunden";
$strWebServerInfo    =  "Webserver Info";
$strLastModified     =  "Zeit der letzten Aktualisierung";
$strNoLastModified   =  "nicht verf&uuml;gbar";
$strLastAccess       =  "Zeit des letzten Zugriffs";
$strNoLastAccess     =  "nicht verf&uuml;gbar";
$strLocation         =  "Ort";
$strSize             =  "Gr&ouml;&szlig;e";
$strTitle            =  "Seitentitel";
$strDescription      =  "Page description";
$strKeywords         =  "Page keywords";
$strSizeAdd          =  "Gr&ouml;&szlig;e der zus&auml;tzlichen Dateien (Bilder, Sounds, ...)";
$strPageWeight       =  "Gesamtgr&ouml;&szlig;e der Seite inkl. zus&auml;tzlicher Dateien (Caching vorausgesetzt)";
$strRetrievingFlag   =  "URL Status";
$strLinkType         =  "Link typ";
$strLinkResult       =  "Ergebnis";
$strLinkDomain       =  "Link domain";
$strHTMLStatement    =  "HTML Element";
$strHTMLStatementRow =  "zeilennummer des HTML-Elements";
$strHTMLAttribute    =  "HTML Attribut";
$strAnchor           =  "Anker";
$strReferer          =  "Referer-URL (Referenzierende URL)";
$strHopCount         =  "Anzahl der Hops (Anzahl der Klicks von der Startseite)";
$strUnknown          =  "Unbekannt";
$strOther            =  "Other";
$strNull             =  "NULL";

/* Page Management */
$strRecordFound   =  "Anzahl der gefundenen Eintr&auml;ge:";
$strListPageInfo  =  "Eintr&auml;ge No. %s bis %s von %s gefundenen Eintr&auml;gen";
$strNext          =  "N&auml;chste";
$strPrevious      =  "Vorherige";
$strFirst         =  "Erste";
$strLast          =  "Letzte";
$strBack          =  "Zur&uuml;ck";
$strAll           =  "Full list";

/* Filters */
$strFilterLinks   =  "Filter f&uuml;r die Liste der Links";
$strLike          =  "gleich";
$strNotLike       =  "nicht gleich";
$strRegExp        =  "RegExp";
$strNotRegExp     =  "Negierte RegExp";
$strGt            =  "gr&ouml;&szlig;er als";
$strLt            =  "kleiner als";

/* List of links page */
$strLinkSubmit    =  "Ausgeben";
$strAllLinks      =  "Alle";
$strOK            =  "OK";
$strNotChecked    =  "Nicht &uuml;berpr&uuml;ft";
$strBroken        =  "Fehlerhafter Link (broken link)";
$strRedirected    =  "Umgeleiteter Link (redirected link)";
$strAnchorNotFound =  "Anker nicht gefunden";
$strNotAuthorized =  "Nicht erlaubt (not authorized)";
$strEMail         =  "E-mail Adresse";
$strJavascript    =  "Javascript URL";
$strBadEncoded    =  "Falsch codierte URL";
$strNormal        =  "Normaler Link";
$strDirect        =  "Direkter Link";
$strRedirection   =  "HTTP Umleitung (HTTP redirection)";
$strSameServer    =  "Same Web server (host:port)";
$strInternal      =  "Internal";
$strExternal      =  "External";
$strHelpOnString  =  "Sie k&ouml;nnen Abfragefilter definieren und diese "
    . "&uuml;ber '\$strLike;' und '\$strNotLike;' verkn&uuml;pfen. "
    . "Erstere liefert alle Resultate die dem angegebenen "
    . "Abfragefilterentsprechen, zweitere all jene Resultate, "
    . "die nicht dem Abfragefilter entsprechen. Sie k&ouml;nnen "
    . "daf&uuml;r 'Wildcard-Zeichen' ('Joker') wie '%' (eine "
    . "beliebige und beliebig lange Zeichenfolge) und '_' (ein "
    . "beliebiges einzelnes Zeichen).";
$strHelpOnRegExp  =  "Wenn Sie die Option '\$strRegExp;' w&auml;hlen, "
    . "k&ouml;nne Sie erweiterte Regular Expression Suchfilter "
    . "verwenden. Es erhalten damit alle jene Datens&auml;tze die "
    . "Ihrer Regular Expression entsprechen. Um alle Datens&auml;tze "
    . "zu erhalten, die nicht Ihrer Regular Expression entsprechen, "
    . "k&ouml;nnen Sie diese mit '\$strNotRegExp;' negieren."; 

/* Show Url page */
$strFilterUrls       =  "Definieren Sie ein Abfragefilter f&uuml;r die Liste der URLs";
$strInfoAvailable    =  "Verf&uuml;gbare Informationen";
$strSizeInfo         =  "Informationen &uuml;ber die Gr&ouml;&szlig;e der Dateien";
$strRetrievingInfo   =  "Informationen &uuml;ber den Empfangsprozess";
$strOutgoingLinks    =  "Informationen &uuml;ber ausgehende Links";
$strIncomingLinks    =  "Informationen &uuml;ber eingehende Links";
$strNotRetrieved     =  "URL nicht geladen";
$strShow             =  "Anzeigen";
$strAllCTypes        =  "Alle";
$strAllCharsets      =  "Alle";
$strAllDocTypes      =  "Alle";
$strAllSCodes        =  "Alle";

/* Show Link page */
$strReferencingUrl   =  "Referenzierender URL (Quell-URL)";
$strReferencedUrl    =  "Ziel-URL";
$strLinkIssued       =  "HTML-Element des Links";
$strOperations       =  "Verf&uuml;gbare weitere Informationen";
$strOpenThisUrl      =  "Diesen URL in einem neuen Browserfenster &ouml;ffnen";
$strShowThisUrlSource   =  "HTML-Quelltext dieser URL anzeigen";
$strOpenReferencingUrl  =  "Referenzierenden URL (Quell-URL) in einem neuen Browserfenster &ouml;ffnen";
$strOpenReferencedUrl   =  "Ziel-URL in einem neuen Browserfenster &ouml;ffnen";

/* Database Drop Page */
$strDBDropSure =  "Sind Sie sicher, dass Sie die gew&auml;hlte "
    . "Datenbank l&ouml;schen wollen? Alle Daten gehen dabei "
    . "unwiederbringlich verloren";
$strDBDrop     =  "Ja, die Datenbank l&ouml;schen";
$strDBCancel   =  "Nein, die Datenbank besser nicht l&ouml;schen";

/* Web structure mining indexes */
$strWSM_Notes = 'Notes';
$strWSM_Indexes = "Indexes of Web Structure Mining";
$strWSM_L = "<strong>L</strong>: links, both ingoing (from different documents) and outgoing for this URL";
$strWSM_D = "<strong>D</strong>: documents, related to this URL by both outgoing and incoming links";
 
$strWSM_OL = "<strong>OL</strong>: outgoing links from this URL to others";
$strWSM_IL = "<strong>IL</strong>: incoming links coming to this URL from different ones";
$strWSM_OD = "<strong>OD</strong>: documents linked to this URL by outgoing links within it";
$strWSM_ID = "<strong>ID</strong>: documents which have links to this URL";
$strWSM_NumOL = "Number of OL";
$strWSM_NumIL = "Number of IL";
$strWSM_NumOD = "Number of OD";
$strWSM_NumID = "Number of ID";
$strWSM_ProOL = "OL/L";
$strWSM_ProIL = "IL/L";
$strWSM_ProOD = "OD/D";
$strWSM_ProID = "ID/D";
$strWSM_RatioL = "OL/IL";
$strWSM_RatioD = "OD/ID";
$strWSM_ExplaL = "Characteristics of links";
$strWSM_ExplaD = "Characteristics of linked  documents";
$strWSM_ExplaIn = "Incoming";
$strWSM_ExplaOut = "Outgoing";
$strWSM_Ratios = "Rapporti";

/* Tidy support */
$strTidyMessages="Diagnose von 'HTML Tidy'";
$strTidyWarnings="Warnungen von 'HTML Tidy'";
$strTidyErrors="Fehlermeldungen von 'HTML Tidy'";
$strTidyHTML="'HTML Tidy' schl&auml;gt den folgenden Quellcode vor";
$strTidyRow="Zeile";
$strTidyColumn="Spalte";
$strErrorNoTidy="Fehler! Das Programm zur &Uuml;berpr&uuml;fung des"
   . " HTML Quellcodes ('HTML Tidy') wurde nicht korrekt konfiguriert."
   . " &Uuml;berpr&uuml;fen Sie die Konfigurationsdatei";
$strErrorNoDirTmp="Fehler! Das tempor&auml;re Verzeichnis von 'HTML"
   . " Tidy' ist ung&uuml;tig. &Uuml;berpr&uuml;fen Sie die Konfigurationsdatei";
$strErrorFileTmp    =  "Fehler! 'HTML Tidy' kann die tempor&auml;ren"
   . " Dateien nicht erstellen. &Uuml;berpr&uuml;fen Sie die Benutzerrechte "
   . " f&uuml;r das tempor&auml;re Verzeichnis von 'HTML Tidy' (Die"
   . " Benutzerrechte m&uuml;ssen jenen des Webservers entsprechen)";

/* Errors */
$strErrorNoDBSelected   =  "Fehler! Es wurde keine Datenbank ausgew&auml;hlt. "
    . "Gehen Sie zur Auswahl zur&uuml;ck.";
$strErrorNoUrlSelected  =  "Fehler Es wurde kein URL ausgew&auml;hlt. "
    . "Gehen Sie zur Auswahl zur&uuml;ck.";
$strErrorMissingInfo    =  "Fehler! Fehlende Angaben. Gehen Sie zur Auswahl zur&uuml;ck.";

/* Open Accessibility Checks (http://checker.atrc.utoronto.ca/) */

$strShowListAchecks      =  "Show the list of accessibility checks (with filter)";
$strListAchecks =  'List of the accessibility errors that have been discovered';
$strAcheckInfo = 'Information regarding the accessibility error';
$strAcheckError = 'Error';
$strAcheckDescription = 'OAC description';
$strAcheckHowToRepair = 'How to repair';
$strAcheckCode       =  "Error code:";
$strSelectAchecks = 'Choose which accessibility errors to search';

$strAchecks = array();

// OAC #1
$strAchecks[1] = array(
	'description' => 'All IMG elements must have an ALT attribute',
	'error' => 'IMG missing ALT attribute',
	'repair' => 'Add an ALT attribute to your IMG element'
);

// OAC #2 
$strAchecks[2] = array(
	'description' => 'IMG element cannot have ALT attribute value '
		. 'that is the same as its SRC attribute',
	'error' => 'Suspicious ALT text (same as filename)',
	'repair' => ''
);

// OAC #3 
$strAchecks[3] = array(
	'description' => 'IMG element must have ALT attribute value of '
		. 'less than 150 characters (English)',
	'error' => 'ALT text may be too long (greater than 150 characters)',
	'repair' => ''
);

// OAC # 7
$strAchecks[7] = array(
	'description' => 'IMG element cannot have ALT attribute value of '
		. 'null or whitespace if the IMG element is contained by an '
		. 'A element',
	'error' => 'Image used as anchor is missing valid ALT text',
	'repair' => 'Modify the text in the ALT attribute to your IMG element'
);

// OAC #27 
$strAchecks[27] = array(
	'description' => 'This error is generated for all BLINK elements',
	'error' => 'BLINK element used',
	'repair' => 'Remove the BLINK element (replace with STRONG or EM)'
);

// OAC #37 
$strAchecks[37] = array(
	'description' => 'First heading element prior to H2 element must be '
		. 'an H1 element',
	'error' => 'Header nesting - H2 does not follow an H1',
	'repair' => 'Modify the header levels so H2 follows H1'
);

// OAC #38 
$strAchecks[38] = array(
	'description' => 'First heading element prior to H3 element must be '
		. 'an H2 element',
	'error' => 'Header nesting - H3 does not follow an H2',
	'repair' => 'Modify the header levels so H3 follows H2'
);

// OAC #39 
$strAchecks[39] = array(
	'description' => 'First heading element prior to H4 element must be '
		. 'an H3 element',
	'error' => 'Header nesting - H4 does not follow an H3',
	'repair' => 'Modify the header levels so H4 follows H3'
);

// OAC #40 
$strAchecks[40] = array(
	'description' => 'First heading element prior to H5 element must be '
		. 'an H4 element',
	'error' => 'Header nesting - H5 does not follow an H4',
	'repair' => 'Modify the header levels so H5 follows H4'
);

// OAC #41 
$strAchecks[41] = array(
	'description' => 'First heading element prior to H6 element must be '
		. 'an H5 element',
	'error' => 'Header nesting - H6 does not follow an H5',
	'repair' => 'Modify the header levels so H6 follows H5'
);

// OAC #48 
$strAchecks[48] = array(
	'description' => 'HTML element must contain a LANG attribute',
	'error' => 'Document language not identified',
	'repair' => 'Add a LANG attribute to the HTML element of your '
		. 'document. The LANG attribute must be set to a valid 2 or '
		. '3 letter language code as defined in the ISO specification 639'
);

// OAC #50 
$strAchecks[50] = array(
	'description' => 'TITLE element must be present in HEAD section of document',
	'error' => 'Document missing TITLE element',
	'repair' => 'Add a TITLE element to the HEAD section of your document'
);

// OAC #51 
$strAchecks[51] = array(
	'description' => 'TITLE element content cannot be empty or whitespace',
	'error' => 'TITLE element is empty',
	'repair' => 'Add text to the TITLE element'
);

// OAC #52 
$strAchecks[52] = array(
	'description' => 'TITLE element content must be less than 150 '
		. 'characters (English)',
	'error' => 'TITLE text may be too long',
	'repair' => ''
);

// OAC #58 
$strAchecks[58] = array(
	'description' => 'INPUT element that contains a TYPE attribute '
		. 'value of "image" must have an ALT attribute',
	'error' => 'Image used for INPUT control is missing ALT text',
	'repair' => 'Add an ALT attribute that describes the image to INPUT control'
);

// OAC #69 
$strAchecks[69] = array(
	'description' => '',
	'error' => 'MARQUEE element should not be used',
	'repair' => ''
);

// OAC #71 
$strAchecks[71] = array(
	'description' => '',
	'error' => 'Auto-redirect should not be used',
	'repair' => ''
);

// OAC #72 
$strAchecks[72] = array(
	'description' => '',
	'error' => 'Auto-refresh should not be used',
	'repair' => ''
);

// OAC #116 
$strAchecks[116] = array(
	'description' => 'This error will be generated for all B elements',
	'error' => 'B element used (use EM or STRONG instead)',
	'repair' => 'Replace your B elements with EM or STRONG'
);

// OAC #117 
$strAchecks[117] = array(
	'description' => 'This error will be generated for all I elements',
	'error' => 'I element used (use EM or STRONG instead)',
	'repair' => 'Replace your I elements with EM or STRONG'
);

/*
// OAC #NUM 
$strAchecks[NUM] = array(
	'description' => 'TXT',
	'error' => 'TXT',
	'repair' => 'TXT'
);
*/

/* ht://Dig notification system */
$strHtDigEmail = 'ht://Dig notify - email address';
$strHtDigEmailSubject = 'ht://Dig notify - subject';
$strHtDigNotificationDate = 'ht://Dig notify - date';

?>
