<?php

//    include/italian.inc
//    Italian sentences and messages
//
//    Part of the ht://Check package
//
//    Copyright (c) 1999-2004 Gabriele Bartolini - Prato - Italy
//    Some portions Copyright (c) 1995-2000 The ht://Dig Group
//
//    For copyright details, see the file COPYING in your distribution
//    or the GNU General Public License version 2 or later 
//    <http://www.gnu.org/copyleft/gpl.html>
//
//    $Id: it.inc.php,v 1.23 2006/08/24 12:53:21 angusgb Exp $

if ( defined( '__ITALIAN_INC' ) ) return;
define( '__ITALIAN_INC', 1 );

/* Main Page */
$strMainPage   =  "Home Page";
$strNumDBs     =  "\$numdbs database di ht://Check sono stati trovati su \$hostname";
$strNoDBs      =  "Mi dispiace. Nessun database di ht://Check è stato trovato su \$hostname";
$strChooseaDB  =  "Scelta";
$strSelectaDB  =  "Scegli un database";

/* Main page of a database */

$strDBSelected =  "Database '<strong>\$dbname</strong>' selezionato";
$strGeneralInfo   = "Informazioni generali";
$strServersEncountered  =  "Server visitati";
$strScheduledURLS =  "URL trovati (sia visitati che scartati)";
$strRetrievedURLS =  "URL effettivamente recuperati";
$strHTMLStatements   =  "Istruzioni HTML";
$strHTMLAttributes   =  "Attributi HTML";
$strLinks      =  "Link";
$strShowListUrls        =  "Mostra la lista completa degli URL trovati";
$strShowListUrlsSeen    =  "Mostra la lista degli URL recuperati";
$strShowNotFoundUrls    =  "Mostra la lista degli URL non trovati (Codice di stato 404)";
$strShowListLinks       =  "Mostra la lista dei link";
$strShowListUrlsFltr    =  "Mostra la lista degli URL recuperati"
   . " (con possibilità di filtro)";

$strHTTPRequestsResults    =  "Riepilogo dei risultati delle richieste HTTP";
$strServersSeenOrdIDServer =  "Riepilogo dei server visitati (ordinati per richieste)";
$strConnectionResults      =  "Riepilogo dei risultati di connessione";
$strContentTypeResults     =  "Riepilogo dei Content-type riscontrati";
$strCookiesReport     =  "Riepilogo dei cookie riscontrati";
$strUser    =  "Utente MySQL che ha eseguito la scansione";
$strStartTime  = "Orario di inizio di htcheck";
$strEndTime  = "Orario di inizio di fine";

/* Sections */
$strListofUrls =  "Lista degli URL recuperati";
$strListofAllUrls =  "Lista di tutti gli URL trovati";
$strListofLinks =  "Lista dei link";
$strShowUrl    =  "Informazioni sull'URL";
$strShowLink   =  "Informazioni sul link";
$strShowUrlSource    =  "Sorgente dell'URL";
$strDBHome =  "Home Page '<strong>\$dbname</strong>'";
$strDBDeletion =  "Cancellazione Database";
$strDBDeleted  =  "Database '<strong>\$dbname</strong>' cancellato";

/* General */

$strUrl              =  "URL";
$strRequests         =  "Richieste";
$strProtocol         =  "Protocollo";
$strConnectionStatus =  "Stato della connessione";
$strContentType      =  "Content type";
$strCharset          =  "Set di caratteri (charset)";
$strDocType          =  "Tipo di documento (doctype)";
$strContentLanguage  =  "Linguaggio del contenuto";
$strTransferEncoding =  "Codifica di trasferimento";
$strStatusCode       =  "Codice di stato";
$strReasonPhrase     =  "Risultato";
$strNumber           =  "Numero";
$strNoOccurrencies   =  "Nessun elemento trovato";
$strWebServerInfo    =  "Informazioni sul server web";
$strLastModified     =  "Data dell'ultima modifica";
$strNoLastModified   =  "non disponibile";
$strLastAccess       =  "Data dell'ultimo accesso";
$strNoLastAccess     =  "non disponibile";
$strLocation         =  "URL redirottato";
$strSize             =  "Dimensione";
$strTitle            =  "Titolo della pagina";
$strDescription      =  "Descrizione della pagina";
$strKeywords         =  "Parole chiave della pagina";
$strSizeAdd          =  "Dimensione aggiuntiva (compreso immagini, ...)";
$strPageWeight       =  "Dimensione complessiva della pagina (supponendo utilizzo cache)";
$strRetrievingFlag   =  "URL contrassegnato come";
$strLinkType         =  "Tipo di link (normale, diretto o redirezione HTTP)";
$strLinkResult       =  "Risultato del Link";
$strLinkDomain       =  "Dominio del Link";
$strHTMLStatement    =  "Istruzione HTML";
$strHTMLStatementRow =  "Numero di riga della istruzione HTML";
$strHTMLAttribute    =  "Attributo HTML";
$strAnchor           =  "Ancora";
$strReferer          =  "URL richiamante";
$strHopCount         =  "Distanza in click dalla pagina iniziale";
$strUnknown          =  "Informazione mancante";
$strOther            =  "Altro";
$strNull             =  "Non definito";
$strServer           =  "Seleziona un server";

/* Page Management */
$strRecordFound   =  "Elementi trovati:";
$strListPageInfo  =  "Lista dal num. %s al %s su %s elementi trovati";
$strNext          =  "Prossimo";
$strPrevious      =  "Precedente";
$strFirst         =  "Inizio";
$strLast          =  "Fine";
$strBack          =  "Indietro";
$strAll           =  "Elenco completo";


/* Filters */
$strFilterLinks   =  "Imposta il filtro per la ricerca dei link";
$strLike          =  "Uguale a";
$strNotLike       =  "Diverso da";
$strRegExp        =  "Espr. Reg.";
$strNotRegExp     =  "Non Espr. Reg.";
$strLinkSubmit    =  "Interroga il database";
$strGt            =  "Maggiore di";
$strLt            =  "Minore di";

/* List of links page */
$strAllLinks      =  "Tutti";
$strOK            =  "OK";
$strNotChecked    =  "Non controllato";
$strBroken        =  "Link Rotto";
$strRedirected    =  "Link Redirottato";
$strAnchorNotFound =  "Ancora non trovata";
$strNotAuthorized =  "Non autorizzato";
$strEMail         =  "Indirizzo e-m@il";
$strJavascript    =  "Javascript";
$strBadEncoded    =  "Errore di codifica URL";
$strNormal        =  "Normale";
$strDirect        =  "Diretto";
$strRedirection   =  "Redirezione HTTP";
$strSameServer    =  "Stesso server";
$strInternal      =  "Interno al dominio";
$strExternal      =  "Esterno al dominio";
$strHelpOnString  =  "E' possibile specificare stringhe di caratteri da ricercare "
                     . "attraverso '$strLike' e '$strNotLike'. La prima "
                     . "restituisce come risultato quei record che soddisfano "
                     . "il criterio di ricerca impostato nel pattern SQL, "
                     . "mentre restituisce il contrario. "
                     . "E' possibile utilizzare caratteri speciali come "
                     . "'%' (qualsiasi sequenza di caratteri) e '_' (qualsiasi "
                     . "singolo carattere).";
$strHelpOnRegExp  =  "Scegliendo '$strRegExp', è possibile utilizzare le "
                     . "espressioni regolari nelle interrogazioni. "
                     . "Vengono restituiti i record che soddisfano i criteri "
                     . "di ricerca impostati. Per ottenere l'inverso, "
                     . "utilizzare '$strNotRegExp'."; 

/* Show Url page */
$strFilterUrls       =  "Imposta il filtro per la ricerca degli URL";
$strInfoAvailable    =  "Informazioni disponibili";
$strSizeInfo         =  "Informazioni riguardanti le dimensioni della risorsa";
$strRetrievingInfo   =  "Informazioni sul processo di recupero della risorsa";
$strOutgoingLinks    =  "Informazioni riguardanti i link 'in uscita' (da questa risorsa)";
$strIncomingLinks    =  "Informazioni riguardanti i link 'in entrata' (verso questa risorsa)";
$strNotRetrieved     =  "URL non recuperato";
$strShow             =  "Visualizza";
$strAllCTypes        =  "Tutti";
$strAllCharsets      =  "Tutti";
$strAllDocTypes      =  "Tutti";
$strAllSCodes        =  "Tutti";
/* Show Link page */
$strReferencingUrl   =  "URL richiamante";
$strReferencedUrl    =  "URL richiamato";
$strLinkIssued       =  "Questo link è stato creato da";
$strOperations       =  "Operazioni disponibili";
$strOpenThisUrl      =  "Apri l'URL in un'altra finestra";
$strShowThisUrlSource   =  "Mostra il sorgente dell'URL in un'altra finestra";
$strShowTidyReport   =  "Mostra il report generato da 'tidy' per questo URL";
$strOpenReferencingUrl  =  "Apri l'URL richiamante in un'altra finestra";
$strOpenReferencedUrl   =  "Apri l'URL richiamato in un'altra finestra";

/* Database Drop Page */
$strDBDropSure =  "Sei sicuro vuoi cancellare il database? "
                  . "Tutti i dati verranno persi per sempre.";
$strDBDrop     =  "Sì, voglio eliminare il database";
$strDBCancel   =  "No, ci ho ripensato ...";

/* Web structure mining indexes */
$strWSM_Notes = 'Note';
$strWSM_Indexes = "Indici di Web Structure Mining";
$strWSM_L = "<strong>L</strong>: link sia in entrata (da documenti diversi) che in uscita relativi a questo URL";
$strWSM_D = "<strong>D</strong>: documenti correlati al presente URL da link sia in entrata che in uscita";

$strWSM_OL = "<strong>LU</strong>: link in uscita verso documenti diversi da questo URL";
$strWSM_IL = "<strong>LE</strong>: link in entrata da documenti diversi verso questo URL";
$strWSM_OD = "<strong>DU</strong>: documenti che sono collegati a questo URL da link in esso presenti";
$strWSM_ID = "<strong>DE</strong>: documenti che hanno al loro interno un link a questo URL";
$strWSM_NumOL = "Numero di LU";
$strWSM_NumIL = "Numero di LE";
$strWSM_NumOD = "Numero di DU";
$strWSM_NumID = "Numero di DE";
$strWSM_ProOL = "LU/L";
$strWSM_ProIL = "LE/L";
$strWSM_ProOD = "DU/D";
$strWSM_ProID = "DE/D";
$strWSM_RatioL = "LU/LE";
$strWSM_RatioD = "DU/DE";
$strWSM_ExplaL = "Caratteristiche dei link";
$strWSM_ExplaD = "Caratteristiche dei documenti collegati";
$strWSM_ExplaIn = "In entrata";
$strWSM_ExplaOut = "In Uscita";
$strWSM_Ratios = "Rapporti";

/* Tidy support */
$strTidyMessages    =  "L'esecuzione di 'tidy' ha prodotto i seguenti 'messaggi'";
$strTidyWarnings    =  "L'esecuzione di 'tidy' ha prodotto le seguenti 'warning'";
$strTidyErrors    =  "L'esecuzione di 'tidy' ha prodotto i seguenti 'errori'";
$strTidyHTML    =  "Ecco il sorgente HTML proposto da 'tidy'";
$strTidyRow    =  "riga";
$strTidyColumn    =  "colonna";
$strErrorNoTidy    =  "Errore! Il programma per la validazione HTML (tidy) non è correttamente impostato.";
$strErrorNoDirTmp    =  "Errore! La directory temporanea per tidy non è valida";
$strErrorFileTmp    =  "Errore! Impossibile scrivere il file temporaneo per tidy";

/* Errors */
$strErrorNoDBSelected   =  "Errore! Nessun database è stato selezionato. Torna indietro.";
$strErrorNoUrlSelected  =  "Errore! Nessun URL è stato selezionato. Torna indietro.";
$strErrorMissingInfo    =  "Errore! Informazioni mancanti. Torna indietro.";

/* Open Accessibility Checks (http://checker.atrc.utoronto.ca/) */

$strShowListAchecks =  'Mostra la lista degli url con errori di accessibilità'
   . ' (con possibilità di filtro)';
$strListAchecks =  "Lista degli errori di accessibilità individuati";
$strAcheckInfo = 'Informazioni disponibili sull\'errore rilevato';
$strAcheckError = 'Errore';
$strAcheckDescription = 'Descrizione OAC';
$strAcheckHowToRepair = 'Come riparare l\'errore';
$strAcheckCode       =  "Codice dell'errore";
$strSelectAchecks = "Scegli fra gli errori di accessibilità da cercare";

$strAchecks = array();

// OAC #1
$strAchecks[1] = array(
	'description' => 'L\'elemento IMG deve avere un attributo ALT',
	'error' => 'IMG senza attributo ALT',
	'repair' => 'Aggiungere l\'attributo ALT all\'elemento IMG'
);

// OAC #2 
$strAchecks[2] = array(
	'description' => 'L\'attributo ALT non può contenere '
		. 'lo stesso valore dell\'attributo SRC',
	'error' => 'ALT contenente il nome del file',
	'repair' => 'Modificare l\'attributo ALT'
);

// OAC #3 
$strAchecks[3] = array(
	'description' => 'L\'attributo ALT dell\'elemento IMG non deve essere '
		. 'più lungo di 150 caratteris',
	'error' => 'Attributo ALT troppo lungo (più di 150 caratteri)',
	'repair' => 'Modificare l\'attributo ALT'
);

// OAC # 7
$strAchecks[7] = array(
	'description' => 'Se l\'elemento IMG è un link, l\'attributo ALT non può '
		. 'essere vuoto o valorizzato con uno spazio',
	'error' => 'ALT non valido per IMG usata come link',
	'repair' => 'Modificare l\'attributo ALT dell\'elemento IMG'
);

// OAC #27 
$strAchecks[27] = array(
	'description' => 'Questo errore è generato per tutti gli elementi BLINK',
	'error' => 'Elemento BLINK',
	'repair' => 'Rimuovere l\'elemento BLINK (sostituirlo con STRONG o EM)'
);

// OAC #37 
$strAchecks[37] = array(
	'description' => '',
	'error' => 'Annidamento sbagliato degli header - H2 non segue un H1',
	'repair' => 'Modificare i livelli degli header in modo che H2 segua H1'
);

// OAC #38 
$strAchecks[38] = array(
	'description' => 'Il primo elemento header che precede un H3 deve essere un elemento H2',
	'error' => 'Annidamento sbagliato degli header - H3 non segue un H2',
	'repair' => 'Modificare i livelli degli header in modo che H3 segua H2'
);

// OAC #39 
$strAchecks[39] = array(
	'description' => 'Il primo elemento header che precede un H4 deve essere un elemento H3',
	'error' => 'Annidamento sbagliato degli header - H4 non segue un H3',
	'repair' => 'Modificare i livelli degli header in modo che H4 segua H3'
);

// OAC #40 
$strAchecks[40] = array(
	'description' => 'Il primo elemento header che precede un H5 deve essere un elemento H4',
	'error' => 'Annidamento sbagliato degli header - H5 non segue un H4',
	'repair' => 'Modificare i livelli degli header in modo che H5 segua H4'
);

// OAC #41 
$strAchecks[41] = array(
	'description' => 'Il primo elemento header che precede un H6 deve essere un elemento H5',
	'error' => 'Annidamento sbagliato degli header - H6 non segue un H5',
	'repair' => 'Modificare i livelli degli header in modo che H6 segua H5'
);

// OAC #48 
$strAchecks[48] = array(
	'description' => 'L\'elemento HTML deve contenere un attributo LANG',
	'error' => 'Linguaggio del documento non identificato',
	'repair' => 'Aggiungere un attributo LANG all\'elemento HTML del tuo '
		. 'documento. L\'attributo LANG deve essere un codice di linguaggio '
		. 'di 2 o 3 lettere come viene definito nelle specifiche ISO 639'
);

// OAC #50 
$strAchecks[50] = array(
	'description' => 'L\'elemento TITLE deve essere presente nella sezione HEAD del documento',
	'error' => 'Mancanza del TITLE nel documento',
	'repair' => 'Aggiungere un elemento TITLE nella sezione HEAD del tuo documento'
);

// OAC #51 
$strAchecks[51] = array(
	'description' => 'L\'elemento TITLE non può essere vuoto o contenere solo spazi',
	'error' => 'TITLE vuoto',
	'repair' => 'Aggiungere del testo all\'elemento TITLE'
);

// OAC #52 
$strAchecks[52] = array(
	'description' => 'L\'elemento TITLE deve contenere meno di 150 caratteri',
	'error' => 'TITLE troppo lungo',
	'repair' => 'Modificare l\'elemento TITLE'
);

// OAC #58 
$strAchecks[58] = array(
	'description' => 'L\'elemento INPUT element che contiene un attributo TYPE '
		. 'valorizzato a "image" deve avere anche un attributo ALT',
	'error' => 'ALT mancante in un\'immagine usata come bottone INPUT',
	'repair' => 'Aggiungere un attributo ALT che descriva l\'immagine del bottone INPUT'
);

// OAC #61 
$strAchecks[61] = array(
	'description' => 'L\'elemento INPUT di tipo immagine non può avere come '
		. 'valore dell\'attributo ALT il nome del file impostato come SRC',
	'error' => 'Immagine utilizzata come elemento INPUT - '
		. 'Testo alternativo sospetto (uguale al nome del file)',
	'repair' => ''
);

// OAC #69 
$strAchecks[69] = array(
	'description' => '',
	'error' => 'Elemento MARQUEE',
	'repair' => ''
);

// OAC #71 
$strAchecks[71] = array(
	'description' => '',
	'error' => 'Auto-redirect',
	'repair' => ''
);

// OAC #72 
$strAchecks[72] = array(
	'description' => '',
	'error' => 'Auto-refresh',
	'repair' => ''
);

// OAC #116 
$strAchecks[116] = array(
	'description' => 'Questo errore è generato per tutti gli elementi B',
	'error' => 'Elemento B',
	'repair' => 'Sostituire l\'elemento B con EM o STRONG'
);

// OAC #117 
$strAchecks[117] = array(
	'description' => 'Questo errore è generato per tutti gli elementi I',
	'error' => 'Elemento I',
	'repair' => 'Sostituire l\'elemento I con EM o STRONG'
);

/*
// OAC #NUM 
$strAchecks[NUM] = array(
	'description' => 'TXT',
	'error' => 'TXT',
	'repair' => 'TXT'
);
*/

/* ht://Dig notification system */
$strHtDigEmail = 'Servizio di notifica di ht://Dig - campo email';
$strHtDigEmailSubject = 'Servizio di notifica di ht://Dig - campo oggetto';
$strHtDigNotificationDate = 'Servizio di notifica di ht://Dig - campo scadenza';

?>
