<?php

//    include/global.inc.php
//    Global variables declaration
//
//    Part of the ht://Check package
//
//    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
//    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
//
//    For copyright details, see the file COPYING in your distribution
//    or the GNU General Public License version 2 or later 
//    <http://www.gnu.org/copyleft/gpl.html>
//
//    $Id: global.inc.php,v 1.7 2003/12/30 09:39:23 angusgb Exp $

if ( defined( '__GLOBAL_INC' ) ) return;
define( '__GLOBAL_INC', 1 );

// Checks for register_globals activation
include ("./include/registerglobals.inc.php");

///////
   //   General Info
///////

$Organisation = "PO-Net Rete Civica di Prato";

///////
   //    Language 
///////

// Language file: automatic detection
if (eregi('^it', $HTTP_ACCEPT_LANGUAGE))
   $Language='it';
else if (eregi('^de', $HTTP_ACCEPT_LANGUAGE))
   $Language='de';
else $Language='en';

// Include it
include ("./include/$Language.inc.php");

///////
   //    Common functions
///////

include ("./include/functions.inc.php");

///////
   //   Database settings
///////

include ("./include/mysqldb.inc.php");
$hostname = "localhost";
$username = "";
$password = "";

// List of database to connect to
// This is a simple array in which you can put the list
// of database you want to connect to. If you leave this
// empty or comment this line out, the script tries to
// recognize a list of ht://Check databases from the
// server specified above. By default this is empty,
// however you can fill it like this:
// $dblist = array ('htcheck', 'htdig');
// Multiple choices must be separated by commas and included
// between single quotes - or even double.

$dblist = array ();

// Create a global instance of the database
$MyDB = new MySQLDB ($hostname, $username, $password);

///////
   //   Session settings
///////

$CookieLifetime = time() + 120;   // Set the lifetime of a cookie

///////
   //   List of links setting
///////

$NumFilterRows = 4;  //Set the number of filter rows in the listlinks.php page
$MaxTagStrLength = 70; // Set the max length of the tag in the list

$MaxURLStrLength = 70; // Set the max length of the URL in the list. This will truncate the URL
                       // name if it is longer than the specified value. Put -1 if you don't want
                       // to snip the rest of the string.

$ShowIcons = true; // D'u want to see the icons or just
                   // the text for link results

// HTML validation tool: tidy (http://tidy.sourceforge.net/)
unset ($Tidy); // Never uncomment this line. It can lead to serious security hole. Indeed
			 // $Tidy is a string containing the path to the executable file to be
			 // launched for HTML source code validation. If you wanna use it
			 // just uncomment the following line or set it to empty.
//$Tidy = '/usr/bin/tidy'; // 'tidy' program command (write the complete path)
$TidyDirTmp = '/tmp';    // do not change it - this directory must be existant - for security reasons

?>
