<?php

//    include/footer.inc.php
//    Footer section of every page
//
//    Part of the ht://Check package
//
//    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
//    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
//
//    For copyright details, see the file COPYING in your distribution
//    or the GNU General Public License version 2 or later 
//    <http://www.gnu.org/copyleft/gpl.html>
//
//    $Id: footer.inc.php,v 1.5 2003/12/30 09:39:23 angusgb Exp $

if ( defined( '__FOOTER_INC' ) ) return;
define( '__FOOTER_INC', 1 );

?>

<br style="clear: both">
</div>

<div id="footer">
<div class="toolbar">
<?php
   if (!empty($linkbar))
	echo $linkbar;
?>
</div>
<div class="img">
<img src="img/htcheck.png" width="158" height="50" alt="ht://Check logo">
</div>
<br style="clear: both">

</div>

</body>
</html>
